@@ -19,8 +19,8 @@ The `event` module handles event management (states, event filter, ...).
 from __future__ import print_function
 
 import weakref
-from guidata.qt.QtCore import QEvent, Qt, QObject, QPointF, Signal
-from guidata.qt.QtGui import QKeySequence
+from qtpy.QtCore import QEvent, Qt, QObject, QPointF, Signal
+from qtpy.QtGui import QKeySequence
 
 CursorShape = type(Qt.ArrowCursor)
 
@@ -31,9 +31,10 @@ from guiqwt.debug import evt_type_to_str, buttons_to_str
 # Sélection d'événements  ---------
 class EventMatch(object):
     """A callable returning true if it matches an event"""
+
     def __call__(self, event):
         raise NotImplementedError
-    
+
     def get_event_types(self):
         """Returns a set of event types handled by this
         EventMatch.
@@ -42,11 +43,13 @@ class EventMatch(object):
         """
         return frozenset()
 
+
 class KeyEventMatch(EventMatch):
     """
     A callable returning True if it matches a key event
     keys: list of keys or couples (key, modifier)
     """
+
     def __init__(self, keys):
         super(KeyEventMatch, self).__init__()
         key_list, mod_list = [], []
@@ -56,8 +59,12 @@ class KeyEventMatch(EventMatch):
             else:
                 k = item
                 # Avoid bad arguments: modifier instead of key
-                assert k not in (Qt.ControlModifier, Qt.ShiftModifier,
-                                 Qt.AltModifier, Qt.NoModifier)
+                assert k not in (
+                    Qt.ControlModifier,
+                    Qt.ShiftModifier,
+                    Qt.AltModifier,
+                    Qt.NoModifier,
+                )
                 m = Qt.NoModifier
             key_list.append(k)
             mod_list.append(m)
@@ -77,14 +84,16 @@ class KeyEventMatch(EventMatch):
                     return True
         return False
 
+
 class StandardKeyMatch(EventMatch):
     """
     A callable returning True if it matches a key event
     keysequence: QKeySequence.StandardKey integer
     """
+
     def __init__(self, keysequence):
         super(StandardKeyMatch, self).__init__()
-        assert isinstance(keysequence, int)
+        assert isinstance(keysequence, (int, QKeySequence.StandardKey))
         self.keyseq = keysequence
 
     def get_event_types(self):
@@ -93,40 +102,45 @@ class StandardKeyMatch(EventMatch):
     def __call__(self, event):
         return event.type() == QEvent.KeyPress and event.matches(self.keyseq)
 
+
 class MouseEventMatch(EventMatch):
     """Base class for matching mouse events"""
-    def __init__(self, evt_type, btn, modifiers = Qt.NoModifier):
+
+    def __init__(self, evt_type, btn, modifiers=Qt.NoModifier):
         super(MouseEventMatch, self).__init__()
-        assert isinstance(modifiers, (int, Qt.KeyboardModifiers))
+        assert isinstance(modifiers, (int, Qt.KeyboardModifiers, Qt.KeyboardModifier))
         self.evt_type = evt_type
         self.button = btn
         self.modifiers = modifiers
-    
+
     def get_event_types(self):
         return frozenset((self.evt_type,))
-    
+
     def __call__(self, event):
         if event.type() == self.evt_type:
             if event.button() == self.button:
                 if self.modifiers != Qt.NoModifier:
                     if (event.modifiers() & self.modifiers) == self.modifiers:
                         return True
-                elif event.modifiers()==Qt.NoModifier:
+                elif event.modifiers() == Qt.NoModifier:
                     return True
         return False
-    
+
     def __repr__(self):
-        return "<MouseMatch: %s/ %08x:%s>" % (evt_type_to_str(self.evt_type),
-                                              self.modifiers,
-                                              buttons_to_str(self.button))
+        return "<MouseMatch: %s/ %08x:%s>" % (
+            evt_type_to_str(self.evt_type),
+            self.modifiers,
+            buttons_to_str(self.button),
+        )
 
 
 class MouseMoveMatch(MouseEventMatch):
     def __call__(self, event):
         if event.type() == self.evt_type:
-            if ((self.button != Qt.NoButton and 
-                 (event.buttons() & self.button == self.button)) or
-                event.buttons() == Qt.NoButton):
+            if (
+                self.button != Qt.NoButton
+                and (event.buttons() & self.button == self.button)
+            ) or event.buttons() == Qt.NoButton:
                 if self.modifiers != Qt.NoModifier:
                     if (event.modifiers() & self.modifiers) == self.modifiers:
                         return True
@@ -140,9 +154,10 @@ class StatefulEventFilter(QObject):
     """Gestion d'une machine d'état pour les événements
     d'un canvas
     """
+
     def __init__(self, parent):
         super(StatefulEventFilter, self).__init__()
-        self.states = { 0 : {} } # 0 : cursor 1: panning, 2: zooming
+        self.states = {0: {}}  # 0 : cursor 1: panning, 2: zooming
         self.cursors = {}
         self.state = 0
         self.max_state = 0
@@ -158,14 +173,14 @@ class StatefulEventFilter(QObject):
             return False
 
         state = self.states[self.state]
-#        from pprint import pprint
-#        print self.state
-#        pprint(state.keys())
+        #        from pprint import pprint
+        #        print self.state
+        #        pprint(state.keys())
         for match, (call_list, next_state) in list(state.items()):
             if match(event):
                 self.set_state(next_state, event)
                 for call in call_list:
-                    call(self, event) # might change state
+                    call(self, event)  # might change state
         return False
 
     def set_state(self, state, event):
@@ -180,13 +195,13 @@ class StatefulEventFilter(QObject):
         cursor = self.get_cursor(event)
         if cursor is not None:
             self.plot.canvas().setCursor(cursor)
-        
+
     def new_state(self):
         """Création (réservation) d'un nouveau numéro d'état"""
         self.max_state += 1
         self.states[self.max_state] = {}
         return self.max_state
-    
+
     def add_event(self, state, match, call, next_state=None):
         """Ajoute une transition sur la machine d'état
         si next_state est fourni, il doit correspondre à un état existant
@@ -195,7 +210,7 @@ class StatefulEventFilter(QObject):
         assert isinstance(state, int)
         assert isinstance(match, EventMatch)
         self.all_event_types = self.all_event_types.union(match.get_event_types())
-        entry = self.states[state].setdefault(match, [ [], None ])
+        entry = self.states[state].setdefault(match, [[], None])
         entry[0].append(call)
         if entry[1] is None:
             if next_state is None:
@@ -207,7 +222,7 @@ class StatefulEventFilter(QObject):
                 assert next_state == entry[1]
             else:
                 next_state = entry[1]
-            
+
         entry[1] = next_state
         return next_state
 
@@ -217,7 +232,7 @@ class StatefulEventFilter(QObject):
         assert isinstance(cursor, CursorShape)
         for s in states:
             self.cursors[s] = cursor
-            
+
     def get_cursor(self, _event):
         """Récupère le curseur associé à un état / événement donné"""
         # on passe event pour eventuellement pouvoir choisir
@@ -231,21 +246,25 @@ class StatefulEventFilter(QObject):
     # Fonction utilitaires
     def mouse_press(self, btn, modifiers=Qt.NoModifier):
         """Création d'un filtre pour l'événement MousePress"""
-        return self.events.setdefault(("mousepress", btn, modifiers),
-                                      MouseEventMatch(QEvent.MouseButtonPress,
-                                                      btn, modifiers))
+        return self.events.setdefault(
+            ("mousepress", btn, modifiers),
+            MouseEventMatch(QEvent.MouseButtonPress, btn, modifiers),
+        )
+
     def mouse_move(self, btn, modifiers=Qt.NoModifier):
         """Création d'un filtre pour l'événement MouseMove"""
-        return self.events.setdefault(("mousemove", btn, modifiers),
-                                      MouseMoveMatch(QEvent.MouseMove,
-                                                     btn, modifiers))
-    
+        return self.events.setdefault(
+            ("mousemove", btn, modifiers),
+            MouseMoveMatch(QEvent.MouseMove, btn, modifiers),
+        )
+
     def mouse_release(self, btn, modifiers=Qt.NoModifier):
         """Création d'un filtre pour l'événement MouseRelease"""
-        return self.events.setdefault(("mouserelease", btn, modifiers),
-                                    MouseEventMatch(QEvent.MouseButtonRelease,
-                                                      btn, modifiers))
-        
+        return self.events.setdefault(
+            ("mouserelease", btn, modifiers),
+            MouseEventMatch(QEvent.MouseButtonRelease, btn, modifiers),
+        )
+
     def nothing(self, filter, event):
         """A nothing filter, provided to help removing duplicate handlers"""
         pass
@@ -255,25 +274,33 @@ class DragHandler(QObject):
     """Classe de base pour les gestionnaires d'événements du type
     click - drag - release
     """
+
     cursor = None
+
     def __init__(self, filter, btn, mods=Qt.NoModifier, start_state=0):
         super(DragHandler, self).__init__()
-        self.state0 = filter.add_event(start_state,
-                                       filter.mouse_press(btn, mods),
-                                       self.start_tracking)
-        self.state1 = filter.add_event(self.state0,
-                                       filter.mouse_move(btn, mods),
-                                       self.start_moving)
-        filter.add_event(self.state1, filter.mouse_move(btn, mods),
-                         self.move, self.state1)
-        filter.add_event(self.state0, filter.mouse_release(btn, mods),
-                         self.stop_notmoving, start_state)
-        filter.add_event(self.state1, filter.mouse_release(btn, mods),
-                         self.stop_moving, start_state)
+        self.state0 = filter.add_event(
+            start_state, filter.mouse_press(btn, mods), self.start_tracking
+        )
+        self.state1 = filter.add_event(
+            self.state0, filter.mouse_move(btn, mods), self.start_moving
+        )
+        filter.add_event(
+            self.state1, filter.mouse_move(btn, mods), self.move, self.state1
+        )
+        filter.add_event(
+            self.state0,
+            filter.mouse_release(btn, mods),
+            self.stop_notmoving,
+            start_state,
+        )
+        filter.add_event(
+            self.state1, filter.mouse_release(btn, mods), self.stop_moving, start_state
+        )
         if self.cursor is not None:
             filter.set_cursor(self.cursor, self.state0, self.state1)
         self.start = None  # first mouse position
-        self.last = None   # mouse position seen during last event
+        self.last = None  # mouse position seen during last event
         self.parent_tracking = None
 
     def get_move_state(self, filter, pos):
@@ -291,8 +318,8 @@ class DragHandler(QObject):
 
     def stop_tracking(self, _filter, _event):
         pass
-        #filter.plot.canvas().setMouseTracking(self.parent_tracking)
-        
+        # filter.plot.canvas().setMouseTracking(self.parent_tracking)
+
     def stop_notmoving(self, filter, event):
         self.stop_tracking(filter, event)
 
@@ -307,17 +334,18 @@ class ClickHandler(QObject):
     """Classe de base pour les gestionnaires d'événements du type
     click - release
     """
-    
+
     #: Signal emitted by ClickHandler on mouse click
-    SIG_CLICK_EVENT = Signal("PyQt_PyObject", "QEvent")
-    
+    SIG_CLICK_EVENT = Signal(object, "QEvent")
+
     def __init__(self, filter, btn, mods=Qt.NoModifier, start_state=0):
         super(ClickHandler, self).__init__()
-        self.state0 = filter.add_event(start_state,
-                                       filter.mouse_press(btn, mods),
-                                       filter.nothing)
-        filter.add_event(self.state0, filter.mouse_release(btn, mods),
-                         self.click, start_state)
+        self.state0 = filter.add_event(
+            start_state, filter.mouse_press(btn, mods), filter.nothing
+        )
+        filter.add_event(
+            self.state0, filter.mouse_release(btn, mods), self.click, start_state
+        )
 
     def click(self, filter, event):
         self.SIG_CLICK_EVENT.emit(filter, event)
@@ -325,6 +353,7 @@ class ClickHandler(QObject):
 
 class PanHandler(DragHandler):
     cursor = Qt.ClosedHandCursor
+
     def move(self, filter, event):
         x_state, y_state = self.get_move_state(filter, event.pos())
         filter.plot.do_pan_view(x_state, y_state)
@@ -332,6 +361,7 @@ class PanHandler(DragHandler):
 
 class ZoomHandler(DragHandler):
     cursor = Qt.SizeAllCursor
+
     def move(self, filter, event):
         x_state, y_state = self.get_move_state(filter, event.pos())
         filter.plot.do_zoom_view(x_state, y_state)
@@ -347,16 +377,16 @@ class MenuHandler(ClickHandler):
 class QtDragHandler(DragHandler):
 
     #: Signal emitted by QtDragHandler when starting tracking
-    SIG_START_TRACKING = Signal("PyQt_PyObject", "QEvent")
-    
+    SIG_START_TRACKING = Signal(object, "QEvent")
+
     #: Signal emitted by QtDragHandler when stopping tracking and not moving
-    SIG_STOP_NOT_MOVING = Signal("PyQt_PyObject", "QEvent")
-    
+    SIG_STOP_NOT_MOVING = Signal(object, "QEvent")
+
     #: Signal emitted by QtDragHandler when stopping tracking and moving
-    SIG_STOP_MOVING = Signal("PyQt_PyObject", "QEvent")
-    
+    SIG_STOP_MOVING = Signal(object, "QEvent")
+
     #: Signal emitted by QtDragHandler when moving
-    SIG_MOVE = Signal("PyQt_PyObject", "QEvent")
+    SIG_MOVE = Signal(object, "QEvent")
 
     def start_tracking(self, filter, event):
         DragHandler.start_tracking(self, filter, event)
@@ -379,9 +409,10 @@ class AutoZoomHandler(ClickHandler):
 
 class MoveHandler(object):
     def __init__(self, filter, btn=Qt.NoButton, mods=Qt.NoModifier, start_state=0):
-        filter.add_event(start_state, filter.mouse_move(btn, mods),
-                         self.move, start_state)
-        
+        filter.add_event(
+            start_state, filter.mouse_move(btn, mods), self.move, start_state
+        )
+
     def move(self, filter, event):
         filter.plot.do_move_marker(event)
 
@@ -390,58 +421,70 @@ class UndoMoveObject(object):
     def __init__(self, obj, pos1, pos2):
         self.obj = obj
         from guiqwt.baseplot import canvas_to_axes
+
         self.coords1 = canvas_to_axes(obj, pos1)
         self.coords2 = canvas_to_axes(obj, pos2)
-        
+
     def is_valid(self):
         return self.obj.plot() is not None
-    
+
     def compute_positions(self):
         from guiqwt.baseplot import axes_to_canvas
+
         pos1 = QPointF(*axes_to_canvas(self.obj, *self.coords1))
         pos2 = QPointF(*axes_to_canvas(self.obj, *self.coords2))
         return pos1, pos2
-    
+
     def undo(self):
         pos1, pos2 = self.compute_positions()
         self.obj.plot().unselect_all()
         self.obj.move_local_shape(pos1, pos2)
-    
+
     def redo(self):
         pos1, pos2 = self.compute_positions()
         self.obj.plot().unselect_all()
         self.obj.move_local_shape(pos2, pos1)
 
+
 class UndoMovePoint(UndoMoveObject):
     def __init__(self, obj, pos1, pos2, handle, ctrl):
         super(UndoMovePoint, self).__init__(obj, pos1, pos2)
         self.handle = handle
         self.ctrl = ctrl
-        
+
     def undo(self):
         pos1, pos2 = self.compute_positions()
         self.obj.move_local_point_to(self.handle, pos1, self.ctrl)
-    
+
     def redo(self):
         pos1, pos2 = self.compute_positions()
         self.obj.move_local_point_to(self.handle, pos2, self.ctrl)
 
+
 class ObjectHandler(object):
-    def __init__(self, filter, btn, mods=Qt.NoModifier, start_state=0,
-                 multiselection=False):
+    def __init__(
+        self, filter, btn, mods=Qt.NoModifier, start_state=0, multiselection=False
+    ):
         self.multiselection = multiselection
         self.start_state = start_state
-        self.state0 = filter.add_event(start_state,
-                                       filter.mouse_press(btn, mods),
-                                       self.start_tracking)
-        filter.add_event(self.state0, filter.mouse_move(btn, mods),
-                         self.move, self.state0)
-        filter.add_event(self.state0, filter.mouse_release(btn, mods),
-                         self.stop_tracking, start_state)
-        filter.add_event(start_state, StandardKeyMatch(QKeySequence.Undo),
-                         self.undo, start_state)
-        filter.add_event(start_state, StandardKeyMatch(QKeySequence.Redo),
-                         self.redo, start_state)
+        self.state0 = filter.add_event(
+            start_state, filter.mouse_press(btn, mods), self.start_tracking
+        )
+        filter.add_event(
+            self.state0, filter.mouse_move(btn, mods), self.move, self.state0
+        )
+        filter.add_event(
+            self.state0,
+            filter.mouse_release(btn, mods),
+            self.stop_tracking,
+            start_state,
+        )
+        filter.add_event(
+            start_state, StandardKeyMatch(QKeySequence.Undo), self.undo, start_state
+        )
+        filter.add_event(
+            start_state, StandardKeyMatch(QKeySequence.Redo), self.redo, start_state
+        )
         self.handle = None  # first mouse position
         self.inside = False
         self._active = None  # mouse position seen during last event
@@ -466,10 +509,10 @@ class ObjectHandler(object):
             self._active = weakref.ref(value)
 
     def add_undo_move_action(self, undo_action):
-        self.undo_stack = self.undo_stack[:self.undo_index+1]
+        self.undo_stack = self.undo_stack[: self.undo_index + 1]
         self.undo_stack.append(undo_action)
         self.undo_index = len(self.undo_stack) - 1
-    
+
     def undo(self, filter, event):
         action = self.undo_stack[self.undo_index]
         if action is not None:
@@ -479,7 +522,7 @@ class ObjectHandler(object):
             else:
                 self.undo_stack.remove(action)
             self.undo_index -= 1
-    
+
     def redo(self, filter, event):
         if self.undo_index < len(self.undo_stack) - 1:
             action = self.undo_stack[self.undo_index + 1]
@@ -489,7 +532,7 @@ class ObjectHandler(object):
                 self.undo_index += 1
             else:
                 self.undo_stack.remove(action)
-        
+
     def start_tracking(self, filter, event):
         plot = filter.plot
         self.inside = False
@@ -500,31 +543,41 @@ class ObjectHandler(object):
         selected = plot.get_active_item()
         distance = CONF.get("plot", "selection/distance", 6)
 
-        (nearest, nearest_dist, nearest_handle,
-         nearest_inside) = plot.get_nearest_object(pos, distance)
+        (
+            nearest,
+            nearest_dist,
+            nearest_handle,
+            nearest_inside,
+        ) = plot.get_nearest_object(pos, distance)
         if nearest is not None:
             # Is the nearest object the real deal?
             if not nearest.can_select() or nearest_dist >= distance:
                 # Looking for the nearest object in z containing cursor position
-                (nearest, nearest_dist, nearest_handle,
-                 nearest_inside) = plot.get_nearest_object_in_z(pos)
-        
+                (
+                    nearest,
+                    nearest_dist,
+                    nearest_handle,
+                    nearest_inside,
+                ) = plot.get_nearest_object_in_z(pos)
+
         # This will unselect active item only if it's not moved afterwards:
         self.unselection_pending = selected is nearest
         if selected and not self.multiselection:
             # An item is selected
             self.active = selected
-            (dist, self.handle, self.inside,
-             other_object) = self.active.hit_test(pos)
+            (dist, self.handle, self.inside, other_object) = self.active.hit_test(pos)
             if other_object is not None:
                 # e.g. LegendBoxItem: 'other_object' is the selected curve
                 plot.set_active_item(other_object)
                 return
             if dist >= distance and not self.inside:
-                # The following allows to move together selected items by 
+                # The following allows to move together selected items by
                 # clicking inside any of them (instead of active item only)
-                other_selitems = [_it for _it in plot.get_selected_items()
-                                  if _it is not self.active and _it.can_move()]
+                other_selitems = [
+                    _it
+                    for _it in plot.get_selected_items()
+                    if _it is not self.active and _it.can_move()
+                ]
                 for selitem in other_selitems:
                     dist, handle, inside, _other = selitem.hit_test(pos)
                     if dist < distance or inside:
@@ -546,20 +599,23 @@ class ObjectHandler(object):
                     if not self.multiselection:
                         plot.unselect_all()
                     plot.select_item(nearest)
-                
+
         # Eventually move or resize selected object:
         self.__move_or_resize_object(dist, distance, event, filter)
         plot.replot()
-        
+
     def __unselect_objects(self, filter):
         """Unselect selected object*s*"""
         plot = filter.plot
         plot.unselect_all()
         plot.replot()
-        
+
     def __move_or_resize_object(self, dist, distance, event, filter):
-        if dist < distance and self.handle is not None \
-           and (self.active.can_resize() or self.active.can_rotate()):
+        if (
+            dist < distance
+            and self.handle is not None
+            and (self.active.can_resize() or self.active.can_rotate())
+        ):
             # Resize / move handle
             self.inside = False
             return
@@ -570,23 +626,23 @@ class ObjectHandler(object):
         filter.set_state(self.start_state, event)
         if self.unselection_pending:
             self.__unselect_objects(filter)
-    
+
     def move(self, filter, event):
         if self.active is None:
             return
         self.unselection_pending = False
         if self.inside:
             self.active.move_local_shape(self.last_pos, event.pos())
-            self.undo_action = UndoMoveObject(self.active, event.pos(),
-                                              self.first_pos)
+            self.undo_action = UndoMoveObject(self.active, event.pos(), self.first_pos)
         else:
             ctrl = event.modifiers() & Qt.ControlModifier == Qt.ControlModifier
             self.active.move_local_point_to(self.handle, event.pos(), ctrl)
-            self.undo_action = UndoMovePoint(self.active, self.first_pos,
-                                             event.pos(), self.handle, ctrl)
+            self.undo_action = UndoMovePoint(
+                self.active, self.first_pos, event.pos(), self.handle, ctrl
+            )
         self.last_pos = QPointF(event.pos())
         filter.plot.replot()
-        
+
     def stop_tracking(self, filter, event):
         self.add_undo_move_action(self.undo_action)
         if self.unselection_pending:
@@ -598,15 +654,15 @@ class ObjectHandler(object):
 class RectangularSelectionHandler(DragHandler):
 
     #: Signal emitted by RectangularSelectionHandler when ending selection
-    SIG_END_RECT = Signal("PyQt_PyObject", "QPointF", "QPointF")
-    
+    SIG_END_RECT = Signal(object, "QPointF", "QPointF")
+
     def __init__(self, filter, btn, mods=Qt.NoModifier, start_state=0):
-        super(RectangularSelectionHandler, self).__init__(filter, btn, mods,
-                                                          start_state)
+        super(RectangularSelectionHandler, self).__init__(
+            filter, btn, mods, start_state
+        )
         self.avoid_null_shape = False
-        
-    def set_shape(self, shape, h0, h1,
-                  setup_shape_cb=None, avoid_null_shape=False):
+
+    def set_shape(self, shape, h0, h1, setup_shape_cb=None, avoid_null_shape=False):
         self.shape = shape
         self.shape_h0 = h0
         self.shape_h1 = h1
@@ -618,7 +674,7 @@ class RectangularSelectionHandler(DragHandler):
 
     def start_moving(self, filter, event):
         self.shape.attach(filter.plot)
-        self.shape.setZ(filter.plot.get_max_z()+1)
+        self.shape.setZ(filter.plot.get_max_z() + 1)
         if self.avoid_null_shape:
             self.start -= QPointF(1, 1)
         self.shape.move_local_point_to(self.shape_h0, self.start)
@@ -628,25 +684,25 @@ class RectangularSelectionHandler(DragHandler):
             self.setup_shape_cb(self.shape)
         self.shape.show()
         filter.plot.replot()
-    
+
     def start_moving_action(self, filter, event):
         """Les classes derivees peuvent surcharger cette methode"""
         pass
-    
+
     def move(self, filter, event):
         self.shape.move_local_point_to(self.shape_h1, event.pos())
         self.move_action(filter, event)
         filter.plot.replot()
-        
+
     def move_action(self, filter, event):
         """Les classes derivees peuvent surcharger cette methode"""
         pass
-    
+
     def stop_moving(self, filter, event):
         self.shape.detach()
         self.stop_moving_action(filter, event)
         filter.plot.replot()
-        
+
     def stop_moving_action(self, filter, event):
         """Les classes derivees peuvent surcharger cette methode"""
         self.SIG_END_RECT.emit(filter, self.start, event.pos())
@@ -662,13 +718,13 @@ def setup_standard_tool_filter(filter, start_state):
     # Bouton du milieu
     PanHandler(filter, Qt.MidButton, start_state=start_state)
     AutoZoomHandler(filter, Qt.MidButton, start_state=start_state)
-    
+
     # Bouton droit
     ZoomHandler(filter, Qt.RightButton, start_state=start_state)
     MenuHandler(filter, Qt.RightButton, start_state=start_state)
-    
+
     # Autres (touches, move)
     MoveHandler(filter, start_state=start_state)
     MoveHandler(filter, start_state=start_state, mods=Qt.ShiftModifier)
     MoveHandler(filter, start_state=start_state, mods=Qt.AltModifier)
-    return start_state
\ No newline at end of file
+    return start_state
