@@ -7,6 +7,8 @@
 
 """Plot computations test"""
 
+from __future__ import unicode_literals
+
 SHOW = True # Show test in GUI-based test launcher
 
 from guiqwt.plot import CurveDialog
@@ -33,16 +35,16 @@ def test():
 
     curve = make.curve(x, y, "ab", "b")
     range = make.range(-2, 2)
-    disp0 = make.range_info_label(range, 'BR', u"x = %.1f ± %.1f cm",
+    disp0 = make.range_info_label(range, 'BR', "x = %.1f ± %.1f cm",
                                   title="Range infos")
 
     disp1 = make.computation(range, "BL", "trapz=%g",
-                             curve, lambda x,y: trapz(y,x))
+                             curve, lambda x, y: trapz(y, x))
 
     disp2 = make.computations(range, "TL",
-                              [(curve, "min=%.5f", lambda x,y: y.min()),
-                               (curve, "max=%.5f", lambda x,y: y.max()),
-                               (curve, "avg=%.5f", lambda x,y: y.mean())])
+                              [(curve, "min=%.5f", lambda x, y: y.min()),
+                               (curve, "max=%.5f", lambda x, y: y.max()),
+                               (curve, "avg=%.5f", lambda x, y: y.mean())])
     legend = make.legend("TR")
     plot( curve, range, disp0, disp1, disp2, legend)
 
