@@ -13,15 +13,16 @@ These plugins provide CurveWidget and ImageWidget objects
 embedding in GUI layouts directly from QtDesigner.
 """
 
-SHOW = True # Show test in GUI-based test launcher
+SHOW = True  # Show test in GUI-based test launcher
 
 import sys, os.path as osp
 
-from guidata.qt.QtGui import QApplication
+from qtpy.QtWidgets import QApplication
 from guiqwt.qtdesigner import loadui
 from guiqwt.builder import make
 
-FormClass = loadui( osp.splitext(__file__)[0]+'.ui' )
+FormClass = loadui(osp.splitext(__file__)[0] + ".ui")
+
 
 class TestWindow(FormClass):
     def __init__(self, image_data):
@@ -30,9 +31,11 @@ class TestWindow(FormClass):
         plot.add_item(make.image(image_data))
         self.setWindowTitle("QtDesigner plugins example")
 
+
 if __name__ == "__main__":
     app = QApplication(sys.argv)
     from guiqwt.tests.image import compute_image
-    form = TestWindow( compute_image() )
+
+    form = TestWindow(compute_image())
     form.show()
     sys.exit(app.exec_())
