@@ -7,8 +7,9 @@
 
 """Internal test related to pcolor feature"""
 
-SHOW = False # Show test in GUI-based test launcher
+from __future__ import print_function
 
+SHOW = False # Show test in GUI-based test launcher
 
 from guiqwt._scaler import _line_test as line
 from numpy import int32, zeros
@@ -21,17 +22,17 @@ def print_tri(imin, imax):
     for i in range(N):
         for j in range(N):
             if j < imin[i] or j > imax[i]:
-                print ".",
+                print(".", end=' ')
             else:
-                print "*",
-        print
+                print("*", end=' ')
+        print()
 
 def test_line(x0, y0, x1, y1):
-    print x0, "," , y0, "->", x1, ",", y1
+    print(x0, ",", y0, "->", x1, ",", y1)
     imin[:] = N
     imax[:] = 0
     line(x0, y0, x1, y1, N, imin, imax)
-    print_tri(imin,imax)
+    print_tri(imin, imax)
 
 if __name__ == '__main__':
     test_line(0, 0, 9, 9)
@@ -41,7 +42,7 @@ if __name__ == '__main__':
     test_line(0, 1, 2, 9)
 
 def test_tri(x0, y0, x1, y1, x2, y2):
-    print x0, ",", y0, "->", x1, ",", y1
+    print(x0, ",", y0, "->", x1, ",", y1)
     imin[:] = N+1
     imax[:] = -1
     line(x0, y0, x1, y1, N, imin, imax)
