@@ -23,9 +23,17 @@ Reference
 
 from __future__ import division, print_function
 
-from guidata.qt.QtGui import (QDialog, QDialogButtonBox, QVBoxLayout, QLabel,
-                              QFormLayout, QLineEdit, QIntValidator, QCheckBox)
-from guidata.qt.QtCore import Qt
+from qtpy.QtWidgets import (
+    QDialog,
+    QDialogButtonBox,
+    QVBoxLayout,
+    QLabel,
+    QFormLayout,
+    QLineEdit,
+    QCheckBox,
+)
+from qtpy.QtGui import QIntValidator
+from qtpy.QtCore import Qt
 
 
 from guiqwt.config import _
@@ -40,10 +48,9 @@ def is_edit_valid(edit):
 
 
 class ResizeDialog(QDialog):
-    def __init__(self, parent, new_size, old_size, text="",
-                 keep_original_size=False):
+    def __init__(self, parent, new_size, old_size, text="", keep_original_size=False):
         QDialog.__init__(self, parent)
-        
+
         intfunc = lambda tup: [int(val) for val in tup]
         if intfunc(new_size) == intfunc(old_size):
             self.keep_original_size = True
@@ -51,42 +58,43 @@ class ResizeDialog(QDialog):
             self.keep_original_size = keep_original_size
         self.width, self.height = new_size
         self.old_width, self.old_height = old_size
-        self.ratio = self.width/self.height
+        self.ratio = self.width / self.height
 
         layout = QVBoxLayout()
         self.setLayout(layout)
-        
+
         formlayout = QFormLayout()
         layout.addLayout(formlayout)
-        
+
         if text:
             label = QLabel(text)
             label.setAlignment(Qt.AlignHCenter)
             formlayout.addRow(label)
-        
+
         self.w_edit = w_edit = QLineEdit(self)
         w_valid = QIntValidator(w_edit)
         w_valid.setBottom(1)
         w_edit.setValidator(w_valid)
-                     
+
         self.h_edit = h_edit = QLineEdit(self)
         h_valid = QIntValidator(h_edit)
         h_valid.setBottom(1)
         h_edit.setValidator(h_valid)
-        
+
         zbox = QCheckBox(_("Original size"), self)
 
         formlayout.addRow(_("Width (pixels)"), w_edit)
         formlayout.addRow(_("Height (pixels)"), h_edit)
-        formlayout.addRow('', zbox)
-        
+        formlayout.addRow("", zbox)
+
         formlayout.addRow(_("Original size:"), QLabel("%d x %d" % old_size))
         self.z_label = QLabel()
         formlayout.addRow(_("Zoom factor:"), self.z_label)
-        
+
         # Button box
-        self.bbox = bbox = QDialogButtonBox(QDialogButtonBox.Ok|
-                                            QDialogButtonBox.Cancel)
+        self.bbox = bbox = QDialogButtonBox(
+            QDialogButtonBox.Ok | QDialogButtonBox.Cancel
+        )
         bbox.accepted.connect(self.accept)
         bbox.rejected.connect(self.reject)
         layout.addWidget(bbox)
@@ -94,9 +102,9 @@ class ResizeDialog(QDialog):
         self.w_edit.setText(str(self.width))
         self.h_edit.setText(str(self.height))
         self.update_widgets()
-        
+
         self.setWindowTitle(_("Resize"))
-        
+
         w_edit.textChanged.connect(self.width_changed)
         h_edit.textChanged.connect(self.height_changed)
         zbox.toggled.connect(self.toggled_no_zoom)
@@ -108,12 +116,12 @@ class ResizeDialog(QDialog):
             if not is_edit_valid(edit):
                 valid = False
         self.bbox.button(QDialogButtonBox.Ok).setEnabled(valid)
-        self.z_label.setText("%d %s" % (100*self.width/self.old_width, '%'))
-        
+        self.z_label.setText("%d %s" % (100 * self.width / self.old_width, "%"))
+
     def width_changed(self, text):
         if is_edit_valid(self.sender()):
             self.width = int(text)
-            self.height = int(self.width/self.ratio)
+            self.height = int(self.width / self.ratio)
             self.h_edit.blockSignals(True)
             self.h_edit.setText(str(self.height))
             self.h_edit.blockSignals(False)
@@ -122,7 +130,7 @@ class ResizeDialog(QDialog):
     def height_changed(self, text):
         if is_edit_valid(self.sender()):
             self.height = int(text)
-            self.width = int(self.ratio*self.height)
+            self.width = int(self.ratio * self.height)
             self.w_edit.blockSignals(True)
             self.w_edit.setText(str(self.width))
             self.w_edit.blockSignals(False)
@@ -137,18 +145,19 @@ class ResizeDialog(QDialog):
             self.update_widgets()
         for widget in (self.w_edit, self.h_edit):
             widget.setDisabled(state)
-        
+
     def get_zoom(self):
         if self.keep_original_size:
             return 1
         elif self.width > self.height:
-            return self.width/self.old_width
+            return self.width / self.old_width
         else:
-            return self.height/self.old_height
+            return self.height / self.old_height
 
-    
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     import guidata
+
     qapp = guidata.qapplication()
     test = ResizeDialog(None, (150, 100), (300, 200), "Enter the new size:")
     if test.exec_():
